@@ -1,8 +1,8 @@
 from .gpal_optimize import gpal_optimize
 from .gpr_instance import GPRInstance
 from .utils import argsConstructor, sequence_with_interval, grid_with_sequences
-from .gpal_plot import plot_convergence, plot_frequency_histogram_1D, plot_frequency_histogram_2D, plot_GPAL_compare_uncertainty, plot_GPAL_uncertainty
-
+from .gpal_plot import plot_frequency_histogram_1D, plot_frequency_histogram_2D, plot_GPAL_compare_uncertainty, plot_GPAL_uncertainty
+from .gpal_plot_new import plot_convergence, plot_GP, plot_selection_frequency
 __all__ = ['gpal_optimize', 
            'GPRInstance', 
            'argsConstructor',
@@ -12,4 +12,6 @@ __all__ = ['gpal_optimize',
            'plot_frequency_histogram_1D',
            'plot_frequency_histogram_2D',
            'plot_GPAL_compare_uncertainty',
-           'plot_GPAL_uncertainty']
\ No newline at end of file
+           'plot_GPAL_uncertainty',
+           'plot_GP', 
+           'plot_selection_frequency']
\ No newline at end of file
