@@ -49,7 +49,7 @@ def gpal_optimize(gpr:GaussianProcessRegressor,
         raise TypeError(f"return_covar should be a bool value, got the type of {type(return_covar).__name__}.")    
 
     if stimulus_candidates.ndim==1:
-        stimulus_candidates=stimulus_candidates.squeeze(-1)
+        stimulus_candidates=stimulus_candidates.reshape(-1,1)
 
     if stimulus_masking_function is None:
         predict_candidates_X=stimulus_candidates
