@@ -368,7 +368,7 @@ def plot_frequency_histogram_1D(fig_size:Tuple[int, int],
         hist=hist/num_data
 
     ## Determining the width of each bar in the figure.
-    bin_width = (ranges[1] - ranges[0]) / bins if ranges else dv1_pos[1] - dv1_pos[0]
+    bin_width = (ranges[1] - ranges[0]) / bins if ranges is not None else dv1_pos[1] - dv1_pos[0]
     ## Determining the position (x-coordinate) of the center of each bar.
     bin_centers = dv1_pos[:-1] + bin_width / 2
     
