@@ -267,7 +267,7 @@ def plot_GP(gp_regressor: GaussianProcessRegressor,
 def plot_selection_frequency(
     dataframe: pd.DataFrame,
     bins: int = 10,
-    x_range: Optional[Tuple[float, float]] = None,
+    val_range: Optional[Tuple[float, float]] = None,
     column_names_specified: Optional[str] = None,
     figure_size: Tuple[int, int] = (10,5), 
     mode: str = 'sum'
@@ -278,16 +278,16 @@ def plot_selection_frequency(
         raise TypeError(f"bins should be an integer value, got the type of {type(bins).__name__}.")
     if not bins>0:
         raise ValueError(f"bins should be a positive integer, got {bins}.")
-    if x_range is not None:
-        if not isinstance(x_range, Tuple):
-            raise TypeError(f"x_range should be a Tuple, got the type of {type(x_range).__name__}.")
+    if val_range is not None:
+        if not isinstance(val_range, Tuple):
+            raise TypeError(f"val_range should be a Tuple, got the type of {type(val_range).__name__}.")
         else:
-            if len(x_range)!=2:
-                raise ValueError(f"x_range should have 2 elements, got {len(x_range)} elements.")
-        if not all([isinstance(r, float) for r in x_range]):
-            raise TypeError(f"x_range should only contain float values.")
-        if x_range[0] >= x_range[1]:
-            raise ValueError(f"x_range[1] should be larger than x_range[0].")
+            if len(val_range)!=2:
+                raise ValueError(f"val_range should have 2 elements, got {len(val_range)} elements.")
+        if not all([isinstance(r, float) for r in val_range]):
+            raise TypeError(f"val_range should only contain float values.")
+        if val_range[0] >= val_range[1]:
+            raise ValueError(f"val_range[1] should be larger than val_range[0].")
     if column_names_specified is not None:
         if not isinstance(column_names_specified, str):
             raise TypeError(f"column_names_specified should be a string value, got the type of {type(column_names_specified).__name__}.")
@@ -332,7 +332,7 @@ def plot_selection_frequency(
             z_data_points = dataframe[z_column_name].tolist()
         '''
     else:
-        x_data_points = dataframe.iloc[:, 0].to_numpy()
+        target_data_points = dataframe.iloc[:, 1].to_numpy()
         '''
         y_data_points = dataframe.iloc[:, 1].tolist()
         '''
@@ -340,17 +340,17 @@ def plot_selection_frequency(
     figure=plt.figure(figsize=figure_size)
     ax= figure.add_subplot(1,1,1)
 
-    if x_range is not None:
-        mask_range = lambda x: x >= x_range[0] and x <= x_range[1]
-        mask_idx = mask_range(x_data_points)
-        x_data_points=x_data_points[mask_idx]
+    if val_range is not None:
+        mask_range = lambda v: v >= val_range[0] and v <= val_range[1]
+        mask_idx = mask_range(target_data_points)
+        target_data_points=target_data_points[mask_idx]
 
-    hist, dv1_pos=np.histogram(x_data_points, bins=bins)
+    hist, dv1_pos=np.histogram(target_data_points, bins=bins)
     
     if mode=='average':
-        hist=hist/len(x_data_points)    ## Determining the width of each bar in the figure.
+        hist=hist/len(target_data_points)    ## Determining the width of each bar in the figure.
 
-    bin_width = (x_range[1] - x_range[0]) / bins if x_range else dv1_pos[1] - dv1_pos[0]
+    bin_width = (val_range[1] - val_range[0]) / bins if val_range is not None else dv1_pos[1] - dv1_pos[0]
 
     bin_centers = dv1_pos[:-1] + bin_width / 2
     
@@ -527,6 +527,6 @@ def plot_convergence(gp_regressor: GaussianProcessRegressor,
     axes[1].grid(True, alpha=0.3)
 
     figure.tight_layout()
-    figure.suptitle("Convergence Plot", fontsize=16, y=1.03)
+    figure.suptitle("Convergence Plot", fontsize=16)
 
     return figure, axes, mse_values
